#!/bin/sh
#
# godiag.sh -- Do diagnostics
#
if test $# != 2
then
    echo "Usage: godiag.sh run slicenum"
else
    run=$1
    slicenum=$2
    infile=out.$run/$run.$slicenum
    outfile=diag.$run.$2
    TR=273.15
    L=2.5e6

    # get that slice and compute stuff
    cdfmath "dent rho / ent =" < $infile | \
	cdfmath "dsatent rho / satent =" | \
	cdfmath "ddryent rho / dryent =" | \
	cdfmath "drt rho / rt =" | \
	cdfmath "drsat rho / rsat =" | \
	cdfmath "ux rho / vx =" | \
	cdfmath "uy rho / vy =" | \
	cdfextr wtgsrcent wtgsrcrt wtgpres wtguz wtgent wtgsatent \
		wtgdryent wtgrt rho ent satent dryent rt rsat rain temp \
		sst keddy surfent surfrt vx vy > tmp0

    # get profiles of interest
    cdfextr wtgpres wtguz wtgent wtgsatent wtgdryent wtgrt ent satent \
	    dryent temp < tmp0 | \
	cdfrdim x 0 160000 | cdfrdim y 0 160000 | \
	cdfextr -s z > tmpwtg

    # saturation fraction
    cdfmath 'rho rt * rhort =' < tmp0 | \
	cdfdefint z | \
	cdfextr rhort | \
	cdfextr -s x y > tmpa
    cdfmath 'rho rsat * rhorsat =' < tmp0 | \
	cdfdefint z | \
	cdfextr rhorsat | \
	cdfextr -s x y > tmpb
    cdfmerge tmpa '' tmpb '' | \
	cdfextr -s x y | \
	cdfmath "rhort rhorsat / sfrac =" | \
	cdfextr sfrac > tmpsf
    rm tmpa tmpb

    # GMS
    cdfmath "wtgsrcent -$TR * gmsnum =" < tmp0 | \
	cdfmath "wtgsrcrt $L * gmsden =" | \
	cdfdefint z | \
	cdfextr -s | \
	cdfextr gmsnum gmsden > tmpgms

    # instability index
    cdfrdim z 1000 3000 < tmp0 | \
	cdfextr -s x y | \
	cdfextr satent > tmpa
    cdfrdim z 5000 7000 < tmp0 | \
	cdfextr -s x y | \
	cdfextr satent > tmpb
    cdfmerge tmpa '' tmpb '' | \
	cdfextr -s x y | \
	cdfmath "satent satent. - ii =" | \
	cdfextr ii > tmpii
    rm tmpa tmpb

    # DCIN and boundary layer
    cdfrdim z 0 500 < tmp0 | \
	cdfextr -s x y | \
	cdfextr ent rain temp sst keddy surfent surfrt vx vy > tmpa
    cdfrdim z 1500 2000 < tmp0 | \
	cdfextr -s x y | \
	cdfextr satent > tmpb
    cdfmerge tmpa '' tmpb '' | \
	cdfextr -s x y | \
	cdfmath "satent ent - dcin =" | \
	cdfmath "ent entbl =" | \
	cdfmath "satent entth =" | \
	cdfmath "temp tempbl =" | \
	cdfmath "vx vxbl =" | \
	cdfmath "vy vybl =" | \
	cdfextr rain entbl entth dcin tempbl sst keddy \
		surfent surfrt vxbl vybl > tmpdcin
    rm tmpa tmpb

    # merge all
    cdfmerge tmpwtg '' tmpsf '' tmpgms '' tmpii '' tmpdcin '' | \
	cdfextr -s x y z | \
	cdfextr -p x0 dx y0 dy z0 dz > $outfile

    rm tmp0 tmpwtg tmpsf tmpgms tmpii tmpdcin
fi
