
#!/bin/sh
#
# goentropy2.sh -- Compute the moist entropy used in paper without
# condensate.
#
if test $# != 4
then
    echo "Usage: goentropy.sh pres(hPa) temp(C) mr(g/kg) ent(J/K/kg)"
else
    pres=$1
    temp=$2
    mr=$3
    ent2=$4

    TF=273.15
    TR=$TF
    CP=1005
    CPV=1850
    CL=4218
    PR=1000
    R=287.05
    RV=461.50
    ESF=6.11
    LFR=2.5008e6
    EPS=0.622

    # the entropy formula is
    # ent = (CP + CPV*mr)*log(ktemp/TR) - R*log((pres - pv)/PR) -
    # mr*RV*log(pv/ESF) + $LFR*mr/TF
    # convert temperature to K and mixing ratio to g/g
    cdfmath "$temp $TF + ktemp =" | cdfmath "$mr 1000 / mr2 =" | \
	cdfmath "mr2 $pres * $EPS / pv =" | \
	cdfmath "ktemp $TF / log $CP $CPV mr2 * + * $ent2 =" | \
	cdfmath "$ent2 $pres pv - $PR / log $R * - $ent2 =" | \
	cdfmath "$ent2 mr2 $RV * pv $ESF / log * - $ent2 =" | \
	cdfmath "$ent2 $LFR mr2 * $TF / + $ent2 ="
fi
