#!/bin/sh
#
# gomakeinit.sh -- Make initialization file from OTREC/PREDICT soundings
# Depends on gootrec_snd.sh
#
if test $# != 16
then
    echo "Usage: gomakeinit.sh ii1 ii2 sfrac1 sfrac2 dcin1 dcin2 sst1 sst2 lon1 lon2 lat1 lat2 vxs vys project title"
else
    ii1=$1
    shift
    ii2=$1
    shift
    sfrac1=$1
    shift
    sfrac2=$1
    shift
    dcin1=$1
    shift
    dcin2=$1
    shift
    sst1=$1
    shift
    sst2=$1
    shift
    lon1=$1
    shift
    lon2=$1
    shift
    lat1=$1
    shift
    lat2=$1
    shift
    vxsys=$1
    shift
    vysys=$1
    shift
    project=$1
    shift
    title=$1
    infile=flat_${project}.cdf
    suffix=${project}_${title}
    midfile=mid_${suffix}.cdf
    outfile=box_${suffix}.cdf
    initfile=init_${suffix}.cdf

    dz=334
    nz=60
    obtop=13000

    cdfuncat index < $infile | \
	cdftsel ii $ii1 $ii2 | \
	cdftsel sfrac $sfrac1 $sfrac2 | \
	cdftsel dcin $dcin1 $dcin2 | \
	cdftsel sst $sst1 $sst2 | \
	cdftsel lonx $lon1 $lon2 | \
	cdftsel latx $lat1 $lat2 | \
	gocat index 0 12000 12000 > $midfile
    cdfrdim index 0 12000 < $midfile > $outfile

    dcin=`cdfsprt.sh dcin < $outfile`
    rain=`cdfsprt.sh rain < $outfile`
    sst=`cdfsprt.sh sst < $outfile`

    gootrec_snd.sh $dz $nz $sst $vxsys $vysys $obtop < $outfile > $initfile

    goplot "10,fs/8,10,6,6,fg/180,320,20,0,16,2,ax/entropy (J~/kg~/K),lx/height (km),ly/ent,z,b,2,p/satent,z,b,2,p/dcin: $dcin1 $dcin2 J~/K~/kg,245,7,ll/rain: $rain W~/m^2,245,8,ll/ii: $ii1 $ii2 J~/K~/kg,245,6,ll/sfrac: $sfrac1 $sfrac2,245,5,ll/SST: $sst1 $sst2 C,245,4,ll/Box: $project $title,tl/8,10,16,6,fg/mass flux (kg~/m^2~/s),lx/height (km),ly/mflux,z,r,p" < $outfile $suffix

    epstopdf $suffix.ps
    rm $suffix.ps $suffix.gri
fi
