#!/bin/sh
#
# gompi.sh -- Start a parallel job using a Go interface.
# Assumes that dronegompi.sh is in $HOME/bin.
#
if test $# -lt 5
then
    echo "Usage: gompi.sh np prog params mach1 procs1 ..."
else

    # number of processes -- should match available slots
    np=$1
    shift

    # program
    prog="$1"
    shift

    # parameters
    params=$1
    shift

    # initialize rank
    rank=0

    # initialize host list
    hlist=""

    # set base port
    port0=12000

    # start with base port
    port=$port0

    # loop over machines listed on command line
    while test $rank -lt $np
    do
	
	# get machine
	mach=$1
	if test "$mach" = ""
	then
	    echo "gorun.sh: Too many processes for available slots"
	    exit 1
	fi
	shift

	# get number of slots for this machine
	slots=$1
	if test "$slots" = ""
	then
	    echo "gorun.sh: Slots missing for last machine"
	    exit 1
	fi
	shift

	# loop over processes for each machine
	proc=0
	while test $proc -lt $slots
	do
	    # bail if more slots than processes
	    if test $rank -ge $np
	    then
		echo "gorun.sh: Too many slots for number of processes"
		exit 1
	    fi

	    # add to host list
	    hlist="${hlist} ${mach}:${port}"

	    # increment port
	    port=$(($port + 1))

	    # increment rank
	    rank=$(($rank + 1))

	    # increment process on this machine
	    proc=$(($proc + 1))
	done
    done

    # replace spaces with underscores for transmission to processes
    xhlist=`echo $hlist | tr " " "_"`

    # loop on processes in the host list
    rank=0
    for proc in $hlist
    do
	
	# pull out machine name
	mach=`echo $proc | cut -d : -f 1`
	
	# start each process, calling
	ssh $mach $HOME/scripts/dronegompi.sh $prog $params $port0 $rank \
	    $xhlist $PWD &

	# increment rank
	rank=$(($rank + 1))
    done
fi
