#!/bin/sh
#
# gootrec_snd.sh -- Interpolate data to the grid used by the goconv model
# and pass the sea surface temperature and the domain propagation
# velocity to gosounding.
# dz and obtop are in meters.
#
if test $# != 6
then
    echo "Usage: gootrec_snd.sh dz nz sst vxsys vysys obtop"
else
    dz=$1
    nz=$2
    sst=$3
    vxsys=$4
    vysys=$5
    obtop=$6

    z0=$(($dz / 2))
    top=$(($dz * $nz))

    cdfuncat z | \
	cdfmath 'z 1000 * z =' | \
	gocat z 0 20000 1001 | \
	cdfsmooth z $dz | \
	cdfinterp z $z0 $dz $nz > barf
    gosounding $sst $vxsys $vysys $obtop < barf
    rm barf
fi
