#!/bin/sh
#
# gosndselect.sh -- Make an initialization file from a particular
# region of a 3DVar analysis.  Depends on gootrec_snd.sh.
#
if test $# != 11
then
    echo "Usage: gosndselect.sh dz nz lon1 lon2 lat1 lat2 vxs vys obtop 3dvarprefix label" 
else
    L=2.5e6
    TREF=273.15

    dz=$1
    shift
    nz=$1
    shift
    lon1=$1
    shift
    lon2=$1
    shift
    lat1=$1
    shift
    lat2=$1
    shift
    vxsys=$1
    shift
    vysys=$1
    shift
    obtop=$1
    shift
    prefix=$1
    shift
    label=$1

    infile=${prefix}.cdf
    
    suffix=${prefix}${label}
    outfile=box_${suffix}.cdf
    initfile=init_${suffix}.cdf

    # compute the ambient wind export of ent and import of mr
    lonlatgrad.sh lon lat ent entx enty < $infile | \
	lonlatgrad.sh lon lat mr mrx mry | \
	cdfwindow lon $lon1 $lon2 | \
	cdfwindow lat $lat1 $lat2 | \
	cdfmean lon .m u v | \
	cdfmean lat .m u.m v.m | \
	cdfmath "rhotherm u.m.m * entx * rhotherm v.m.m * enty * + $TREF * srcenth0 =" | \
	cdfmath "rhotherm u.m.m * mrx * rhotherm v.m.m * mry * + -1e-3 * $L * srcmrh0 =" | \
	cdfextr srcenth0 srcmrh0 | \
	cdfrdim lon $lon1 $lon2 | \
	cdfrdim lat $lat1 $lat2 | \
	cdfdefint z | \
	cdfextr -s > tmpfile

    # create box file
    cdfmerge $infile '' tmpfile '' | \
	cdfextr -s lon lat z | \
	cdfrdim lon $lon1 $lon2 | \
	cdfrdim lat $lat1 $lat2 | \
	cdfparams lon1 $lon1 | \
	cdfparams lon2 $lon2 | \
	cdfparams lat1 $lat1 | \
	cdfparams lat2 $lat2 > $outfile

    rm tmpfile

    sst=`cdfsprt.sh sst < $outfile`

    # create init file
    gootrec_snd.sh $dz $nz $sst $vxsys $vysys $obtop < $outfile > $initfile
fi
