#!/bin/sh
#
# gosummary.sh -- Summarize the output of a WTG run.
if test $# != 3
then
    echo "Usage: gosummary.sh casenum time1 time2"
else
    casenum=$1
    time1=$2
    time2=$3

    # x and y boundary layer velocity
    cdfrdim z 0 1000 < prof.$casenum | \
	cdfextr -s time | \
	cdfextr vx vy > tmp1

    # saturation fraction
    cdfrdim z 0 20000 < prof.$casenum | \
	cdfmath "drt drsat / sfrac =" | \
	cdfextr -s time | \
	cdfextr sfrac > tmp2

    # instability index
    cdfrdim z 1000 3000 < prof.$casenum | \
	cdfextr satent > lo.cdf
    cdfrdim z 5000 7000 < prof.$casenum | \
	cdfextr satent > hi.cdf
    cdfmerge lo.cdf '' hi.cdf '' | \
	cdfmath 'satent satent. - ii =' | \
	cdfextr -s time | \
	cdfextr ii > tmp3

    # dcin
    cdfrdim z 0 1000 < prof.$casenum | \
	cdfextr ent > lo.cdf
    cdfrdim z 1500 2000 < prof.$casenum | \
	cdfextr satent > hi.cdf
    cdfmerge lo.cdf '' hi.cdf '' | \
	cdfmath 'satent ent - dcin =' | \
	cdfextr -s time | \
	cdfextr dcin > tmp7

    # gross moist stability
    TREF=273.15
    L=2.5e6
    cdfrdim z 0 20000 < prof.$casenum | \
	cdfderiv surfent2 surfentcum time | \
	cdfderiv wtgsrcent2 wtgsrcentcum time | \
	cdfderiv wtgsrcrt2 wtgsrcrtcum time | \
	cdfmath "wtgsrcent2 $TREF * -1 * 20000 * ngmsnum =" | \
	cdfmath "wtgsrcrt2 $L * 20000 * ngmsden =" | \
	cdfmath "sdrad $TREF * 20000 * sdrad =" | \
	cdfmath "surfent2 $TREF * surfent2 =" | \
	cdfmath "surfent2 sdrad + ngmsnum - enttend =" | \
	cdfextr -s time | \
	cdfextr ngmsnum ngmsden sdrad surfent2 enttend > tmp4

    # moisture convergence
    cdfrdim z 0 20000 < prof.$casenum | \
	cdfmath "wtgsrcrt 20000 * 86400 * rconv =" | \
	cdfextr -s time | \
	cdfextr rconv > tmp5

    # rainfall and surface evaporation
    cdfderiv rain2 raincum time < prof.$casenum | \
	cdfderiv surfrt2 surfrtcum time | \
	cdfmath 'rain2 86400 * dayrain =' | \
	cdfmath 'surfrt2 86400 * daysurfrt =' | \
	cdfextr dayrain daysurfrt | \
	cdfextr -s time > tmp6

    # mass flux indices
    cdfrdim z 3000 5000 < prof.$casenum | \
	cdfmath "wtguz mfluxlo =" | \
	cdfextr mfluxlo | \
	cdfextr -s time > tmp8lo
    cdfrdim z 7000 9000 < prof.$casenum | \
	cdfmath "wtguz mfluxhi =" | \
	cdfextr mfluxhi | \
	cdfextr -s time > tmp8hi
    cdfmerge tmp8lo '' tmp8hi '' | \
	cdfmath "mfluxhi mfluxlo - mfluxdif =" | \
	cdfextr -s time > tmp8
    rm tmp8lo tmp8hi

    # merge everything
    cdfmerge tmp1 '' tmp2 '' tmp3 '' tmp4 '' tmp5 '' \
	     tmp6 '' tmp7 '' tmp8 '' > sum.$casenum

    # print time averages
    cdfrdim time $time1 $time2 < sum.$casenum | \
	cdfmath 'ngmsnum ngmsden / ngms =' | \
	cdflook | \
	egrep ' vx = | vy = | sfrac = | ii = | ngms = | ngmsnum = | rconv = | ngmsden = | dayrain = | daysurfrt = | dcin = | sdrad = | surfent2 = | enttend = | mfluxlo = | mfluxhi = | mfluxdif = '

    # clean up
    rm lo.cdf hi.cdf tmp1 tmp2 tmp3 tmp4 tmp5 tmp6 tmp7 tmp8

    # create a time-mean file
    cdfrdim time $time1 $time2 < prof.$casenum > mean.$casenum
fi
