// params -- Read parameters for a model run from a file and make
// available to the model
package params

import (
	"fmt"
	"strings"
	"sio"
	"os"
	"strconv"
)

const (
	maxbytes = 10000
)

// this reads the parameter file and creates a map of parameter-value
// pairs.  Lines shorter than two tokens or ones with the first token
// beginning with "#" are ignored.
func Getparams(filename string, paramlist map[string]string) {

	// grab stuff from the specified file
	pfile, err := sio.Open(filename)
	if err != nil {
		fmt.Println("Getparams: can't find file",filename)
		os.Exit(1)
	}
	buff, _ := sio.Get(pfile,5000)
	stuff := string(buff)
	plines := strings.Split(stuff,"\n")
	for _, pline := range plines {
		ptokens := strings.Fields(pline)
		if len(ptokens) < 2 || ptokens[0][0] == '#' {
			continue
		}
		paramlist[ptokens[0]] = ptokens[1]
	}
	return
}

// extract a string parameter value
func Sparam(paramlist map[string]string, pname string) (pval string) {
	pval, ok := paramlist[pname]
	if ok {
		return
	} else {
		fmt.Println("Getparam: parameter",pname,"not found")
		os.Exit(1)
	}
	return
}

// extract a float64 parameter value
func Fparam(paramlist map[string]string, pname string) (float64) {
	pstr, ok := paramlist[pname]
	if ok {
		pval, err := strconv.ParseFloat(pstr, 64)
		if err != nil {
			fmt.Println("Getparam: parameter",pname,"not float")
			os.Exit(1)
		}
		return pval
	} else {
		fmt.Println("Getparam: parameter",pname,"not found")
		os.Exit(1)
		return float64(0.0)
	}
}

// extract an int parameter value
func Iparam(paramlist map[string]string, pname string) (int) {
	pstr, ok := paramlist[pname]
	if ok {
		pval64, err := strconv.ParseInt(pstr, 0, 0)
		pval := int(pval64)
		if err != nil {
			fmt.Println("Getparam: parameter",pname,"not int")
			os.Exit(1)
		}
		return pval
	} else {
		fmt.Println("Getparam: parameter",pname,"not found")
		os.Exit(1)
		return int(0)
	}
}
